@@ -7,28 +7,26 @@ use io_lifetimes::AsFilelike;
     target_os = "openbsd",
     target_os = "redox",
 )))]
-use posish::fs::fadvise;
+use rsix::fs::fadvise;
 #[cfg(any(target_os = "ios", target_os = "macos"))]
-use posish::fs::fcntl_rdadvise;
+use rsix::fs::fcntl_rdadvise;
 #[cfg(not(any(
     windows,
     target_os = "netbsd",
     target_os = "redox",
     target_os = "openbsd"
 )))]
-use posish::fs::{fallocate, FallocateFlags};
+use rsix::fs::{fallocate, FallocateFlags};
 #[cfg(not(any(windows, target_os = "ios", target_os = "macos", target_os = "redox")))]
-use posish::io::{preadv, pwritev};
-use std::{
-    convert::TryInto,
-    fmt::Arguments,
-    io::{self, IoSlice, IoSliceMut, Read, Seek, SeekFrom, Write},
-    slice,
-};
+use rsix::io::{preadv, pwritev};
+use std::convert::TryInto;
+use std::fmt::Arguments;
+use std::io::{self, IoSlice, IoSliceMut, Read, Seek, SeekFrom, Write};
+use std::slice;
 #[cfg(windows)]
 use {cap_fs_ext::Reopen, std::fs, std::os::windows::fs::FileExt};
 #[cfg(not(windows))]
-use {posish::fs::tell, posish::fs::FileExt};
+use {rsix::fs::tell, rsix::fs::FileExt};
 
 /// Advice to pass to `FileIoExt::advise`.
 #[cfg(not(any(
@@ -43,17 +41,17 @@ use {posish::fs::tell, posish::fs::FileExt};
 #[repr(i32)]
 pub enum Advice {
     /// No advice; default heuristics apply.
-    Normal = posish::fs::Advice::Normal as i32,
+    Normal = rsix::fs::Advice::Normal as i32,
     /// Data will be accessed sequentially at ascending offsets.
-    Sequential = posish::fs::Advice::Sequential as i32,
+    Sequential = rsix::fs::Advice::Sequential as i32,
     /// Data will be accessed with an irregular access pattern.
-    Random = posish::fs::Advice::Random as i32,
+    Random = rsix::fs::Advice::Random as i32,
     /// Data will be accessed soon.
-    WillNeed = posish::fs::Advice::WillNeed as i32,
+    WillNeed = rsix::fs::Advice::WillNeed as i32,
     /// Data will not be accessed soon.
-    DontNeed = posish::fs::Advice::DontNeed as i32,
+    DontNeed = rsix::fs::Advice::DontNeed as i32,
     /// Data will be accessed exactly once.
-    NoReuse = posish::fs::Advice::NoReuse as i32,
+    NoReuse = rsix::fs::Advice::NoReuse as i32,
 }
 
 /// Advice to pass to `FileIoExt::advise`.
@@ -119,9 +117,10 @@ pub trait FileIoExt {
     /// Reads the exact number of byte required to fill buf from the given
     /// offset.
     ///
-    /// This is similar to [`std::os::unix::fs::FileExt::read_exact_at`], except
-    /// it takes `self` by immutable reference since the entire side effect is
-    /// I/O, and it's supported on non-Unix platforms including Windows.
+    /// This is similar to [`std::os::unix::fs::FileExt::read_exact_at`],
+    /// except it takes `self` by immutable reference since the entire side
+    /// effect is I/O, and it's supported on non-Unix platforms including
+    /// Windows.
     ///
     /// [`std::os::unix::fs::FileExt::read_exact_at`]: https://doc.rust-lang.org/std/os/unix/fs/trait.FileExt.html#tymethod.read_exact_at
     fn read_exact_at(&self, buf: &mut [u8], offset: u64) -> io::Result<()>;
@@ -178,7 +177,8 @@ pub trait FileIoExt {
         Ok(())
     }
 
-    /// Determines if this `Read`er has an efficient `read_vectored_at` implementation.
+    /// Determines if this `Read`er has an efficient `read_vectored_at`
+    /// implementation.
     #[inline]
     fn is_read_vectored_at(&self) -> bool {
         false
@@ -222,8 +222,8 @@ pub trait FileIoExt {
 
     /// Attempts to write an entire buffer into this writer.
     ///
-    /// This is similar to [`std::io::Write::write_all`], except it takes `self`
-    /// by immutable reference since the entire side effect is I/O.
+    /// This is similar to [`std::io::Write::write_all`], except it takes
+    /// `self` by immutable reference since the entire side effect is I/O.
     ///
     /// [`std::io::Write::write_all`]: https://doc.rust-lang.org/std/io/trait.Write.html#tymethod.write_all
     fn write_all(&self, buf: &[u8]) -> io::Result<()>;
@@ -294,21 +294,24 @@ pub trait FileIoExt {
         Ok(())
     }
 
-    /// Determines if this `Write`r has an efficient `write_vectored_at` implementation.
+    /// Determines if this `Write`r has an efficient `write_vectored_at`
+    /// implementation.
     #[inline]
     fn is_write_vectored_at(&self) -> bool {
         false
     }
 
-    /// Writes a formatted string into this writer, returning any error encountered.
+    /// Writes a formatted string into this writer, returning any error
+    /// encountered.
     ///
-    /// This is similar to [`std::io::Write::write_fmt`], except it takes `self` by
-    /// immutable reference since the entire side effect is I/O.
+    /// This is similar to [`std::io::Write::write_fmt`], except it takes
+    /// `self` by immutable reference since the entire side effect is I/O.
     ///
     /// [`std::io::Write::write_fmt`]: https://doc.rust-lang.org/std/io/trait.Write.html#tymethod.write_fmt
     fn write_fmt(&self, fmt: Arguments) -> io::Result<()>;
 
-    /// Flush this output stream, ensuring that all intermediately buffered contents reach their destination.
+    /// Flush this output stream, ensuring that all intermediately buffered
+    /// contents reach their destination.
     ///
     /// This is similar to [`std::io::Write::flush`], except it takes `self` by
     /// immutable reference since the entire side effect is I/O.
@@ -413,12 +416,12 @@ impl<T: AsFilelike> FileIoExt for T {
     #[inline]
     fn advise(&self, offset: u64, len: u64, advice: Advice) -> io::Result<()> {
         let advice = match advice {
-            Advice::WillNeed => posish::fs::Advice::WillNeed,
-            Advice::Normal => posish::fs::Advice::Normal,
-            Advice::Sequential => posish::fs::Advice::Sequential,
-            Advice::NoReuse => posish::fs::Advice::NoReuse,
-            Advice::Random => posish::fs::Advice::Random,
-            Advice::DontNeed => posish::fs::Advice::DontNeed,
+            Advice::WillNeed => rsix::fs::Advice::WillNeed,
+            Advice::Normal => rsix::fs::Advice::Normal,
+            Advice::Sequential => rsix::fs::Advice::Sequential,
+            Advice::NoReuse => rsix::fs::Advice::NoReuse,
+            Advice::Random => rsix::fs::Advice::Random,
+            Advice::DontNeed => rsix::fs::Advice::DontNeed,
         };
         Ok(fadvise(self, offset, len, advice)?)
     }
@@ -603,8 +606,8 @@ impl<T: AsFilelike> FileIoExt for T {
 
     #[inline]
     fn allocate(&self, _offset: u64, _len: u64) -> io::Result<()> {
-        // We can't faithfully support allocate on Windows without exposing race conditions.
-        // Instead, refuse:
+        // We can't faithfully support allocate on Windows without exposing race
+        // conditions. Instead, refuse:
         Err(io::Error::new(
             io::ErrorKind::PermissionDenied,
             "file allocate is not supported on Windows",
